Registo | OiRA

Temas

# Registo

## Por que razão tenho de me registar?

A primeira coisa que lhe será solicitada quando iniciar a sua primeira avaliação de riscos é criar uma conta OiRA — um processo simples e rápido.

O registo permite-lhe iniciar uma sessão em qualquer momento para aceder aos seus dados, continuar avaliações anteriormente iniciadas ou iniciar novas avaliações.

Efetuar o registo significa que o sistema OiRA pode guardar todas as suas sessões e que os seus dados estarão sempre disponíveis.

Leia a nossa política de privacidade e saiba como lidamos com os seus dados pessoais.

## Qual é a diferença entre registar-se como utilizador e fazer uma sessão de teste?

A sessão de teste permite às partes interessadas visualizar a ferramenta antes de decidir efetuar o seu registo. No entanto, durante uma sessão de teste, os seus dados não serão guardados e não poderá recuperar posteriormente informações que tenha inserido. A sessão de teste não lhe permite imprimir nenhum relatório, ao passo que, se tiver efetuado o registo, a sua conta permite-lhe documentar integralmente a sua avaliação de riscos.

## Registar-se com uma nova conta

É a sua primeira visita? Siga estas etapas simples para iniciar:

1) Clique em «Registar» para visualizar o formulário de registo.

Formulário de registo.

2) Introduza o seu endereço de correio eletrónico e defina uma palavra-passe (introduzir duas vezes)

3) Clique em «Seguinte» para registar a sua nova conta.

4) Leia e aceite a política de privacidade para continuar

Já estará então ligado ao sistema OiRA.

## Iniciar sessão com uma conta já criada

Se já efetuou o seu registo anteriormente, poderá aceder à sua conta da seguinte forma:

1) Aceda ao formulário de início de sessão. Será apresentada uma ligação para o formulário de início de sessão sempre que tentar aceder a OiRA e até que inicie a sua sessão.

Formulário de início de sessão.

2) Introduza o seu endereço de correio eletrónico e a sua palavra-passe.

3) Aceda ao sistema clicando no botão «Iniciar sessão».

Depois de iniciada a sessão, verá o ecrã seguinte. A partir desse ecrã, pode iniciar uma nova avaliação de riscos ou retornar às avaliações de risco que tenha iniciado anteriormente.

O painel de comandos.

Inicie uma nova avaliação de riscos atribuindo-lhe um título (por exemplo, A-minha-empresa 2018-07-03) ou aceda a uma avaliação de riscos que já tenha criado anteriormente. Todas as avaliações de risco são guardadas para referência futura, a menos que opte por eliminá-las.

Scroll to top Load toolbar…
Back

## 1-registration.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More